import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { setTheme } from 'ngx-bootstrap/utils';
import { __decorate, __metadata, __awaiter } from 'tslib';
import { Component, HostBinding, NgModule } from '@angular/core';
import { BaseUIComponent, ContainerProperties, propDescription, DataModelProperties, StyleProperties, getItemByIndex, CoreService, CoreModule } from '@ngx-dynamic-components/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const packageName = 'bootstrap';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ContainerComponent extends BaseUIComponent {
    constructor() {
        super(...arguments);
        this.isContainer = true;
        this.isFluidContainer = false;
        this.height = 'auto';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        const _super = Object.create(null, {
            ngOnInit: { get: () => super.ngOnInit }
        });
        return __awaiter(this, void 0, void 0, function* () {
            yield _super.ngOnInit.call(this);
            if (this.properties.fullWidth) {
                this.isFluidContainer = true;
                this.isContainer = false;
            }
            if (this.properties.height) {
                this.height = this.properties.height;
            }
        });
    }
}
ContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-container',
                template: `
    <dc-container-row *ngFor="let item of uiModel.children" [ngStyle]="getStyles(item.itemProperties)"
      (changedDataModel)="changedDataModel.emit($event)"
      [uiModel]='item'
      [dataModel]='dataModel'
      [workflowEngine]='workflowEngine'
    ></dc-container-row>
  `,
                styles: [`
    :host {
      display: block;
    }
  `]
            }] }
];
ContainerComponent.propDecorators = {
    isContainer: [{ type: HostBinding, args: ['class.container',] }],
    isFluidContainer: [{ type: HostBinding, args: ['class.container-fluid',] }],
    height: [{ type: HostBinding, args: ['style.height',] }]
};
class BSContainerProperties extends ContainerProperties {
}
__decorate([
    propDescription({
        description: 'Is full width container, default false',
        example: 'true',
    }),
    __metadata("design:type", Boolean)
], BSContainerProperties.prototype, "fullWidth", void 0);
/** @type {?} */
const example = {
    title: 'Bootstrap container example',
    uiModel: {
        type: 'bootstrap:container',
        containerProperties: {
            width: '100%'
        },
        itemProperties: {
            width: '20%',
            padding: '10px'
        },
        children: [{
                type: 'bootstrap:bs-row',
                children: [{
                        type: 'bootstrap:text-input',
                        containerProperties: {},
                        itemProperties: {
                            label: 'Input-1',
                            placeholder: 'Name first section',
                            dataModelPath: '$.first'
                        }
                    }, {
                        type: 'bootstrap:text-input',
                        containerProperties: {},
                        itemProperties: {
                            label: 'Input-2',
                            placeholder: 'Name second section',
                            dataModelPath: '$.second'
                        }
                    }]
            }, {
                type: 'bootstrap:bs-row',
                children: [{
                        type: 'bootstrap:text-input',
                        containerProperties: {},
                        itemProperties: {
                            label: 'Input-11',
                            placeholder: 'Name third section',
                            dataModelPath: '$.third'
                        }
                    }, {
                        type: 'bootstrap:text-input',
                        containerProperties: {},
                        itemProperties: {
                            label: 'Input-22',
                            placeholder: 'Name fourth section',
                            dataModelPath: '$.forth'
                        }
                    }]
            }]
    },
    dataModel: {}
};
/** @type {?} */
const containerDescriptor = {
    name: 'container',
    packageName,
    category: "Layout" /* Layout */,
    description: 'Bootstrap container',
    itemProperties: BSContainerProperties,
    component: ContainerComponent,
    example
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ContainerRowComponent extends BaseUIComponent {
    constructor() {
        super(...arguments);
        this.isRow = true;
        this.isColumn = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        const _super = Object.create(null, {
            ngOnInit: { get: () => super.ngOnInit }
        });
        return __awaiter(this, void 0, void 0, function* () {
            yield _super.ngOnInit.call(this);
            this.isColumn = this.properties && this.properties.direction === 'column';
        });
    }
}
ContainerRowComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-container-row',
                template: `
    <div *ngFor="let item of uiModel.children" class="col" [ngStyle]="getStyles(item.containerProperties)"
      [ngClass]="item.containerProperties?.bsClasses">
      <dc-ui-selector
          (changedDataModel)="changedDataModel.emit($event)"
          [uiModel]='item'
          [dataModel]='dataModel'
          [workflowEngine]='workflowEngine'
      ></dc-ui-selector>
    </div>
  `
            }] }
];
ContainerRowComponent.propDecorators = {
    isRow: [{ type: HostBinding, args: ['class.row',] }],
    isColumn: [{ type: HostBinding, args: ['class.flex-column',] }]
};
class BSContainerRowProperties extends ContainerProperties {
}
__decorate([
    propDescription({
        description: 'Bootstrap row child classes',
        example: 'col-9'
    }),
    __metadata("design:type", Array)
], BSContainerRowProperties.prototype, "bsClasses", void 0);
__decorate([
    propDescription({
        description: 'Flex direction',
        example: 'column'
    }),
    __metadata("design:type", String)
], BSContainerRowProperties.prototype, "direction", void 0);
/** @type {?} */
const example$1 = {
    title: 'Bootstrap container row example',
    uiModel: {
        type: 'bootstrap:bs-row',
        containerProperties: {
            width: '100%'
        },
        itemProperties: {
            width: '50%',
            padding: '10px'
        },
        children: [{
                type: 'bootstrap:text-input',
                containerProperties: {},
                itemProperties: {
                    label: 'Input-1',
                    placeholder: 'Name first section',
                    dataModelPath: '$.first'
                }
            }, {
                type: 'bootstrap:text-input',
                containerProperties: {},
                itemProperties: {
                    label: 'Input2',
                    placeholder: 'Name second section',
                    dataModelPath: '$.second'
                }
            }]
    },
    dataModel: {}
};
/** @type {?} */
const containerRowDescriptor = {
    name: 'bs-row',
    packageName: 'bootstrap',
    category: 'Layout',
    description: 'Bootstrap row container',
    itemProperties: BSContainerRowProperties,
    component: ContainerRowComponent,
    example: example$1
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class InputUIComponent extends BaseUIComponent {
    /**
     * @return {?}
     */
    get id() {
        return 'input-id-' + this.properties.label.replace(/ /g, '-').toLowerCase();
    }
}
InputUIComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-input-ui',
                template: `
  <div class="form-group" [ngStyle]="containerStyles">
    <ng-container *ngIf="properties.label; else noLabel">
      <label [for]="id">{{properties.label}}</label>
      <input [id]="id" [type]="properties.type || 'text'" class="form-control"
        [placeholder]="properties.placeholder"
        [ngStyle]="itemStyles"
        (input)="changedDataModel.emit(this.dataModel)"
        [(ngModel)]="componentDataModel">
    </ng-container>
    <ng-template #noLabel>
      <input [type]="properties.type || 'text'" class="form-control"
        [placeholder]="properties.placeholder"
        [ngStyle]="itemStyles"
        (input)="changedDataModel.emit(this.dataModel)"
        [(ngModel)]="componentDataModel">
    </ng-template>
  </div>
  `
            }] }
];
class InputProperties extends DataModelProperties {
}
__decorate([
    propDescription({
        description: 'Text shown when field is empty',
        example: 'Type your name',
    }),
    __metadata("design:type", String)
], InputProperties.prototype, "placeholder", void 0);
/** @type {?} */
const example$2 = {
    title: 'Text input example',
    uiModel: {
        type: `${packageName}:text-input`,
        containerProperties: {},
        itemProperties: {
            label: 'Name',
            placeholder: 'Enter your name',
            dataModelPath: '$.name'
        }
    },
    dataModel: {}
};
/** @type {?} */
const inputDescriptor = {
    name: 'text-input',
    packageName,
    category: "Form control" /* FormControl */,
    description: 'Input component',
    itemProperties: InputProperties,
    component: InputUIComponent,
    example: example$2
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SelectUIComponent extends BaseUIComponent {
    /**
     * @return {?}
     */
    onSelect() {
        this.changedDataModel.emit(this.dataModel);
        this.triggerAction('_selectionChanged');
    }
    /**
     * @return {?}
     */
    get disabled() {
        /** @type {?} */
        const options = this.properties.options;
        return options && options.length ? null : 'disabled';
    }
}
SelectUIComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-select-ui',
                template: `
    <div class="form-group" [ngStyle]="containerStyles">
      <label *ngIf="properties.label" selected>{{properties.label}}</label>
      <select class="form-control" [ngStyle]="itemStyles"
        (change)="onSelect()"
        [(ngModel)]="componentDataModel" [attr.disabled]="disabled">
        <option *ngFor="let option of properties.options" [value]="option.value">{{option.label}}</option>
      </select>
    </div>
  `
            }] }
];
class SelectProperties extends DataModelProperties {
}
__decorate([
    propDescription({
        description: 'Select options.',
        example: '[{label: "One", value: 1}]',
    }),
    __metadata("design:type", Array)
], SelectProperties.prototype, "options", void 0);
__decorate([
    propDescription({
        description: 'Label shown when no option is selected.',
        example: 'Please select an option',
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "label", void 0);
/** @type {?} */
const example$3 = {
    uiModel: {
        type: `${packageName}:select`,
        containerProperties: {},
        id: 'stateSelection',
        itemProperties: {
            options: [
                { label: 'United Kingdom', value: 'uk' },
                { label: 'Ukraine', value: 'ua' }
            ],
            label: 'Country',
            dataModelPath: '$.country'
        }
    },
    dataModel: {},
    title: 'Basic select example'
};
/** @type {?} */
const selectDescriptor = {
    name: 'select',
    packageName,
    category: "Form control" /* FormControl */,
    description: 'Select component',
    itemProperties: SelectProperties,
    component: SelectUIComponent,
    example: example$3
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CheckboxUIComponent extends BaseUIComponent {
}
CheckboxUIComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-checkbox-ui',
                template: `
    <div class="form-check" [ngClass]="{'form-check-inline': properties.inline}" [ngStyle]="containerStyles">
      <input class="form-check-input" type="checkbox"
      [ngStyle]="itemStyles"
      (change)="changedDataModel.emit(this.dataModel)"
      [(ngModel)]="componentDataModel">
      <label *ngIf="properties.label" class="form-check-label">{{properties.label}}</label>
    </div>
  `
            }] }
];
class CheckboxProperties extends DataModelProperties {
}
__decorate([
    propDescription({
        description: 'Label',
        example: 'Accept conditions.',
    }),
    __metadata("design:type", String)
], CheckboxProperties.prototype, "label", void 0);
__decorate([
    propDescription({
        description: 'Inline',
        example: 'true',
    }),
    __metadata("design:type", Boolean)
], CheckboxProperties.prototype, "inline", void 0);
/** @type {?} */
const example$4 = {
    title: 'Checkbox example',
    uiModel: {
        type: `${packageName}:checkbox`,
        containerProperties: {},
        itemProperties: {
            label: 'Accept conditions',
            padding: '10px',
            margin: '20px',
            dataModelPath: '$.accept',
            inline: true
        }
    },
    dataModel: {}
};
/** @type {?} */
const checkboxDescriptor = {
    name: 'checkbox',
    packageName,
    category: "Form control" /* FormControl */,
    description: 'Checkbox component',
    itemProperties: CheckboxProperties,
    component: CheckboxUIComponent,
    example: example$4
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class RadioGroupUIComponent extends BaseUIComponent {
    /**
     * @param {?} option
     * @return {?}
     */
    onChange(option) {
        this.componentDataModel = option.value;
        this.changedDataModel.emit(this.dataModel);
    }
}
RadioGroupUIComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-radio-group-ui',
                template: `
    <div class="form-check" *ngFor="let option of properties.options"
      [ngClass]="{'form-check-inline': properties.inline}" [ngStyle]="itemStyles">
      <input class="form-check-input" type="radio"
      (change)="onChange(option)"
      [name]="properties.dataModelPath" [value]="option.value">
      <label class="form-check-label">{{option.label}}</label>
    </div>
  `
            }] }
];
class RadioGroupProperties extends DataModelProperties {
}
__decorate([
    propDescription({
        description: 'Label',
        example: 'Select color',
    }),
    __metadata("design:type", String)
], RadioGroupProperties.prototype, "label", void 0);
__decorate([
    propDescription({
        description: 'Radio group options',
        example: '[{label: "One", value: 1}]',
    }),
    __metadata("design:type", Array)
], RadioGroupProperties.prototype, "options", void 0);
__decorate([
    propDescription({
        description: 'Radio options inline',
        example: 'true',
    }),
    __metadata("design:type", String)
], RadioGroupProperties.prototype, "inline", void 0);
/** @type {?} */
const example$5 = {
    title: 'Radio group example',
    uiModel: {
        type: `${packageName}:radio-group`,
        containerProperties: {},
        itemProperties: {
            label: 'Select color',
            padding: '5px 20px',
            margin: '10px 0',
            dataModelPath: '$.color',
            options: [{ label: 'White', value: 'white' }, { label: 'Black', value: 'black' }],
        }
    },
    dataModel: {}
};
/** @type {?} */
const radioGroupDescriptor = {
    name: 'radio-group',
    packageName,
    category: "Form control" /* FormControl */,
    description: 'Radio group component',
    itemProperties: RadioGroupProperties,
    component: RadioGroupUIComponent,
    example: example$5
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TextareaUIComponent extends BaseUIComponent {
}
TextareaUIComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-textarea-ui',
                template: `
    <div class="form-group" [ngStyle]="itemStyles">
      <label *ngIf="properties.label">{{properties.label}}</label>
      <textarea class="form-control"
        [rows]="properties.rows"
        [placeholder]="properties.placeholder"
        [ngStyle]="itemStyles"
        (input)="changedDataModel.emit(this.dataModel)"
        [(ngModel)]="componentDataModel"></textarea>
    </div>
  `
            }] }
];
class TextareaProperties extends DataModelProperties {
}
__decorate([
    propDescription({
        description: 'Number of rows in textarea',
        example: '5',
    }),
    __metadata("design:type", Number)
], TextareaProperties.prototype, "rows", void 0);
__decorate([
    propDescription({
        description: 'Text shown when field is empty',
        example: 'Type about yourself',
    }),
    __metadata("design:type", String)
], TextareaProperties.prototype, "placeholder", void 0);
__decorate([
    propDescription({
        description: 'Text area label',
        example: 'Type about yourself',
    }),
    __metadata("design:type", String)
], TextareaProperties.prototype, "label", void 0);
/** @type {?} */
const example$6 = {
    title: 'Text area example',
    uiModel: {
        type: `${packageName}:textarea`,
        containerProperties: {},
        itemProperties: {
            rows: 10,
            placeholder: 'Type information about yourself',
            dataModelPath: '$.info'
        }
    },
    dataModel: {}
};
/** @type {?} */
const textareaDescriptor = {
    name: 'textarea',
    packageName,
    category: "Form control" /* FormControl */,
    description: 'Text area component',
    itemProperties: TextareaProperties,
    component: TextareaUIComponent,
    example: example$6
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ButtonUIComponent extends BaseUIComponent {
    /**
     * @return {?}
     */
    onClick() {
        this.workflowEngine.run(this.properties.clickActionKey);
        this.changedDataModel.emit(this.dataModel);
    }
}
ButtonUIComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-button-ui',
                template: `
    <button class="btn " [ngClass]="properties.btnClass || 'btn-primary'"
      [type]="properties.type" [ngStyle]="itemStyles"
      (click)="onClick()">{{properties.label}}</button>
  `
            }] }
];
class ButtonProperties extends StyleProperties {
}
__decorate([
    propDescription({
        description: 'Button label',
        example: 'Click me!',
    }),
    __metadata("design:type", String)
], ButtonProperties.prototype, "label", void 0);
__decorate([
    propDescription({
        description: 'Key for action that fires onclick',
        example: 'submit',
    }),
    __metadata("design:type", String)
], ButtonProperties.prototype, "clickActionKey", void 0);
__decorate([
    propDescription({
        description: 'Bootstrap predefined button class',
        example: 'btn-secondary',
    }),
    __metadata("design:type", String)
], ButtonProperties.prototype, "btnClass", void 0);
__decorate([
    propDescription({
        description: 'Button type: button|submit|reset. Default: button',
        example: 'submit',
    }),
    __metadata("design:type", String)
], ButtonProperties.prototype, "type", void 0);
/** @type {?} */
const example$7 = {
    title: 'Basic button example',
    uiModel: {
        type: `${packageName}:button`,
        containerProperties: {},
        itemProperties: {
            label: 'SUBMIT',
            width: '50%',
            margin: '15px',
            padding: '10px 5px 10px 0px',
            clickActionKey: 'consoleLog'
        }
    },
    dataModel: {}
};
/** @type {?} */
const buttonDescriptor = {
    name: 'button',
    packageName,
    category: "Buttons" /* Buttons */,
    description: 'Button component',
    itemProperties: ButtonProperties,
    component: ButtonUIComponent,
    example: example$7
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CardComponent extends BaseUIComponent {
    /**
     * @return {?}
     */
    get header() {
        return this.getChildByIndex(0);
    }
    /**
     * @return {?}
     */
    get content() {
        return this.getChildByIndex(1);
    }
    /**
     * @return {?}
     */
    get footer() {
        return this.getChildByIndex(2);
    }
    /**
     * @private
     * @param {?} index
     * @return {?}
     */
    getChildByIndex(index) {
        return getItemByIndex(this.uiModel.children, index);
    }
}
CardComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-card',
                template: `
  <div class="card">
    <div class="card-header" *ngIf="header">
      <dc-ui-selector
        (changedDataModel)="changedDataModel.emit(this.dataModel)"
        [uiModel]='header'
        [dataModel]='dataModel'
        [workflowEngine]='workflowEngine'></dc-ui-selector>
    </div>
    <div class="card-body" *ngIf="content">
      <dc-ui-selector
        (changedDataModel)="changedDataModel.emit(this.dataModel)"
        [uiModel]='content'
        [dataModel]='dataModel'
        [workflowEngine]='workflowEngine'></dc-ui-selector>
    </div>
    <div class="card-footer" *ngIf="footer">
      <dc-ui-selector
        (changedDataModel)="changedDataModel.emit(this.dataModel)"
        [uiModel]='footer'
        [dataModel]='dataModel'
        [workflowEngine]='workflowEngine'></dc-ui-selector>
    </div>
  </div>`
            }] }
];
class CardProperties extends ContainerProperties {
}
__decorate([
    propDescription({
        description: 'Card can have 3 children, 1 - header, 2 - content, 3 - footer.',
        example: `[null, {
      type: 'material:text',
      containerProperties: {},
      itemProperties: {
        text: 'Card content text',
      }
    }, null]`,
    }),
    __metadata("design:type", Array)
], CardProperties.prototype, "children", void 0);
/** @type {?} */
const example$8 = {
    title: 'Card panel example',
    uiModel: {
        type: 'bootstrap:card',
        containerProperties: {},
        itemProperties: {
            padding: '10px',
            margin: '10px auto',
            width: '80%'
        },
        children: [{
                type: 'material:text',
                containerProperties: {},
                itemProperties: {
                    text: 'Card header text',
                    width: '100%'
                }
            }, {
                type: 'material:textarea',
                containerProperties: {
                    width: '100%',
                },
                itemProperties: {
                    rows: 4,
                    placeholder: 'Type card information',
                    dataModelPath: '$.card/info'
                }
            }, {
                type: 'bootstrap:button',
                containerProperties: {},
                itemProperties: {
                    label: 'Submit',
                    margin: '16px',
                    width: '50%',
                    clickActionKey: 'consoleLog'
                }
            }]
    },
    dataModel: {}
};
/** @type {?} */
const cardDescriptor = {
    name: 'card',
    packageName,
    category: "Layout" /* Layout */,
    description: 'Card layout component',
    itemProperties: CardProperties,
    component: CardComponent,
    example: example$8
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const COMPONENTS_LIST = [
    containerDescriptor,
    containerRowDescriptor,
    inputDescriptor,
    selectDescriptor,
    checkboxDescriptor,
    radioGroupDescriptor,
    textareaDescriptor,
    buttonDescriptor,
    cardDescriptor
];
// Register components.
/**
 * @return {?}
 */
function registerComponents() {
    COMPONENTS_LIST.forEach((/**
     * @param {?} component
     * @return {?}
     */
    component => CoreService.registerComponent(component)));
}
/**
 * @return {?}
 */
function getCategories() {
    /** @type {?} */
    const categories = COMPONENTS_LIST.reduce((/**
     * @param {?} map
     * @param {?} desc
     * @return {?}
     */
    (map, desc) => {
        map[desc.category] = map[desc.category] || [];
        map[desc.category].push(desc);
        return map;
    }), {});
    return Object.entries(categories).map((/**
     * @param {?} __0
     * @return {?}
     */
    ([key, val]) => {
        return {
            name: key,
            components: val,
            packageName
        };
    }));
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BootstrapModule {
    constructor() {
        setTheme('bs4');
        registerComponents();
    }
}
BootstrapModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ContainerComponent, ContainerRowComponent, InputUIComponent, SelectUIComponent,
                    CheckboxUIComponent, RadioGroupUIComponent, TextareaUIComponent, ButtonUIComponent, CardComponent],
                imports: [
                    CoreModule,
                    CommonModule,
                    FormsModule
                ],
                exports: [ContainerComponent, ContainerRowComponent, InputUIComponent],
                entryComponents: [ContainerComponent, ContainerRowComponent, InputUIComponent, SelectUIComponent,
                    CheckboxUIComponent, RadioGroupUIComponent, TextareaUIComponent, ButtonUIComponent, CardComponent]
            },] }
];
/** @nocollapse */
BootstrapModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { COMPONENTS_LIST, getCategories, BootstrapModule, ButtonProperties as ɵbd, ButtonUIComponent as ɵbc, buttonDescriptor as ɵbf, example$7 as ɵbe, CardComponent as ɵbg, CardProperties as ɵbh, cardDescriptor as ɵbi, CheckboxProperties as ɵr, CheckboxUIComponent as ɵq, checkboxDescriptor as ɵt, example$4 as ɵs, BSContainerRowProperties as ɵf, ContainerRowComponent as ɵe, containerRowDescriptor as ɵh, example$1 as ɵg, BSContainerProperties as ɵb, ContainerComponent as ɵa, containerDescriptor as ɵd, example as ɵc, InputProperties as ɵj, InputUIComponent as ɵi, example$2 as ɵk, inputDescriptor as ɵl, RadioGroupProperties as ɵv, RadioGroupUIComponent as ɵu, example$5 as ɵw, radioGroupDescriptor as ɵx, SelectProperties as ɵn, SelectUIComponent as ɵm, example$3 as ɵo, selectDescriptor as ɵp, TextareaProperties as ɵz, TextareaUIComponent as ɵy, example$6 as ɵba, textareaDescriptor as ɵbb, packageName as ɵbj };

//# sourceMappingURL=ngx-dynamic-components-bootstrap.js.map